Documentation
¶
Index ¶
Constants ¶
Variables ¶
var ErrBufferFull = errors.New("retry buffer full")
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
HTTPRelays []HTTPConfig `toml:"http"`
UDPRelays []UDPConfig `toml:"udp"`
}
func LoadConfigFile ¶
LoadConfigFile parses the specified file into a Config object
type HTTP ¶
type HTTP struct {
// contains filtered or unexported fields
}
HTTP is a relay for HTTP influxdb writes
type HTTPConfig ¶
type HTTPConfig struct {
// Name identifies the HTTP relay
Name string `toml:"name"`
// Addr should be set to the desired listening host:port
Addr string `toml:"bind-addr"`
// Set certificate in order to handle HTTPS requests
SSLCombinedPem string `toml:"ssl-combined-pem"`
// Default retention policy to set for forwarded requests
DefaultRetentionPolicy string `toml:"default-retention-policy"`
// Outputs is a list of backed servers where writes will be forwarded
Outputs []HTTPOutputConfig `toml:"output"`
}
type HTTPOutputConfig ¶
type HTTPOutputConfig struct {
// Name of the backend server
Name string `toml:"name"`
// Location should be set to the URL of the backend server's write endpoint
Location string `toml:"location"`
// Timeout sets a per-backend timeout for write requests. (Default 10s)
// The format used is the same seen in time.ParseDuration
Timeout string `toml:"timeout"`
// Buffer failed writes up to maximum count. (Default 0, retry/buffering disabled)
BufferSizeMB int `toml:"buffer-size-mb"`
// Maximum batch size in KB (Default 512)
MaxBatchKB int `toml:"max-batch-kb"`
// Maximum delay between retry attempts.
// The format used is the same seen in time.ParseDuration (Default 10s)
MaxDelayInterval string `toml:"max-delay-interval"`
// Skip TLS verification in order to use self signed certificate.
// WARNING: It's insecure. Use it only for developing and don't use in production.
SkipTLSVerification bool `toml:"skip-tls-verification"`
}
type UDP ¶
type UDP struct {
// contains filtered or unexported fields
}
UDP is a relay for UDP influxdb writes
type UDPConfig ¶
type UDPConfig struct {
// Name identifies the UDP relay
Name string `toml:"name"`
// Addr is where the UDP relay will listen for packets
Addr string `toml:"bind-addr"`
// Precision sets the precision of the timestamps (input and output)
Precision string `toml:"precision"`
// ReadBuffer sets the socket buffer for incoming connections
ReadBuffer int `toml:"read-buffer"`
// Outputs is a list of backend servers where writes will be forwarded
Outputs []UDPOutputConfig `toml:"output"`
}
type UDPOutputConfig ¶
Click to show internal directories.
Click to hide internal directories.